# :studio_microphone: Notion Audio Journal

<!-- WARNING: THIS FILE WAS AUTOGENERATED! DO NOT EDIT! -->

## Getting started

``` bash
pip install audio-journal
```

After you’ve update the `~/.audio-journal/config` with your [page
ID](https://github.com/ramnes/notion-sdk-py/discussions/31) and
[integration key](https://www.notion.so/my-integrations)

``` bash
audio_journal_start
```

## Demo

https://user-images.githubusercontent.com/5474861/236587909-a7b0578b-b742-4571-80a2-65e249c43fca.mp4

## Why?

I wish I journaled more often. The ability to look back through the
years, reflect and remember events long past is invaluable.

While the benefits of hand written journaling are clear, forcing one to
slow down, to organize one’s thoughts, I find the 5x slow down makes it
a non-starter. So instead lets optimize for gross word count!

## Future work

- Offer alternative storage options
- Interface with a mic, always on, wait for wake word
